==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/PointSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { PointSeriesDescription } from "./PointSeriesDescription";
/**
 * @hidden
 */
export let PointSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PointSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PointSeriesDescriptionMetadata.a == null) {
                PointSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PointSeriesDescriptionMetadata.c(PointSeriesDescriptionMetadata.a);
            }
            if (a.k(PointSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(PointSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            PointSeriesDescriptionMetadata.b(a);
            a.ad("PointSeries", () => new PointSeriesDescription());
            a.ac("PointSeries", PointSeriesDescriptionMetadata.a);
        }
    }
    PointSeriesDescriptionMetadata.$t = markType(PointSeriesDescriptionMetadata, 'PointSeriesDescriptionMetadata');
    PointSeriesDescriptionMetadata.a = null;
    return PointSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/PointSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { PointSeriesDescription } from "./PointSeriesDescription";
/**
 * @hidden
 */
export let PointSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PointSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PointSeriesDescriptionMetadata.a == null) {
                PointSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PointSeriesDescriptionMetadata.c(PointSeriesDescriptionMetadata.a);
            }
            if (a.k(PointSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(PointSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            PointSeriesDescriptionMetadata.b(a);
            a.ae("PointSeries", () => new PointSeriesDescription());
            a.ad("PointSeries", PointSeriesDescriptionMetadata.a);
        }
    }
    PointSeriesDescriptionMetadata.$t = markType(PointSeriesDescriptionMetadata, 'PointSeriesDescriptionMetadata');
    PointSeriesDescriptionMetadata.a = null;
    return PointSeriesDescriptionMetadata;
})();
